﻿/*
 * mics.js
 * v2.0.0
 * 2010/08/31
 */

(function () {

	//create namespace "YAHOO.JP.lib.mics"
	YAHOO = typeof YAHOO === "undefined" ? {} : YAHOO;
	YAHOO.JP = typeof YAHOO.JP === "undefined" ? {} : YAHOO.JP;
	YAHOO.JP.lib = typeof YAHOO.JP.lib === "undefined" ? {} : YAHOO.JP.lib;

	/**
	 * @namespace YAHOO.JP.lib.micsy
	 */
	YAHOO.JP.lib.mics = typeof YAHOO.JP.lib.mics === "undefined" ? {} : YAHOO.JP.lib.mics;
	var M = YAHOO.JP.lib.mics;

	/**
	 * レイアウトの初期化を行う（メニューバーを隠し、かつレイアウトを更新）
	 * @methodOf YAHOO.JP.lib.mics
	 * @name initLayout
	 * @static
	 */
	M.initLayout = function () {
		if (navigator.userAgent.indexOf('iP') !== -1 && window.location.hash === "") {
			window.setTimeout(window.scrollTo, 0, 0, 1);
		}
		window.setTimeout(M.updateLayout, 0);
		M.addEvent(window, "resize", M.updateLayout);
		if (typeof window.onorientationchange === "object") {
			M.addEvent(window, "orientationchange", M.updateLayout);
		} else { 
			M.addEvent(window, "resize", M.updateLayout);
		}
	};

	/**
	 * レイアウトの更新を行う（縦型であればportrait、横型であればlandscapeというクラス名をbody要素に付加）
	 * @methodOf YAHOO.JP.lib.mics
	 * @name updateLayout
	 * @static
	 */
	M.updateLayout = function () {
		if (window.orientation !== undefined) {
			var d = document.body,
				orient;
	    	switch (window.orientation) {
			case 0:
			    orient = "portrait";
			    break;
			case 90:
			case -90:
				orient = "landscape";
			    break;
			default:
				orient = "portrait";
				break;
			}
			M.switchClass(d, d.className, orient); 
		}
	};

	/**
	 * 指定したクラス名に適合する要素の配列を返す
	 * @methodOf YAHOO.JP.lib.mics
	 * @name getClass
	 * @static
	 * @param {Object} el クラスを取得する要素
	 * @param {string} searchClass 検索するクラス
	 * @param {string} tag クラスの取得対象の要素種別
	 * @return {array} returnArr searchClass名を持つ配列
	 */
	M.getClass = function (el, searchClass, tag) {
		if (el) {
			var returnArr = [], els, pattern, i;
			if (typeof document.getElementsByClassName === "function") {
				returnArr = el.getElementsByClassName(searchClass, tag);
			} else { 
				tag = tag || '*';
				els = el.getElementsByTagName(tag);
				pattern = new RegExp('(^|\\s)' + searchClass + '(\\s|$)');
				for (i = 0; i < els.length; i = i + 1) {
					if (pattern.test(els[i].className)) {
				    	returnArr.push(els[i]);
					}
				}
			}
			return returnArr;
		}
	};

	/**
	 * 指定したクラス名があるかを返す
	 * @methodOf YAHOO.JP.lib.mics
	 * @name hasClass
	 * @static
	 * @param {Object} el The CSS selector string or DOM node
	 * @param {String} className The class name.
	 * @return True if the node has the class name applied to it, false otherwise.
	 */	
	M.hasClass = function (el, className) 
	{
		var hasClass = false;
		if (el && el.className) 
		{
			hasClass = (el.className.match(new RegExp('(?:^|\\s+)' + className + '(?:\\s+|$)')) !== null);
		}
		return hasClass;
	};

	/**
	 * 指定したクラス名を追加する
	 * @methodOf YAHOO.JP.lib.mics
	 * @name addClass
	 * @static
	 * @param {Object} el 
	 * @param {String} className 
	 */	
	M.addClass = function (el, className) 
	{
		if (el) 
		{
			if (!el.className.match(className)) 
			{
				el.className += ' ' + className;
			}				
		}
	};

	/**
	 * 指定したクラス名を削除する
	 * @methodOf YAHOO.JP.lib.mics
	 * @name removeClass
	 * @static
	 * @param {Object} el The CSS selector string or DOM node
	 * @param {String} className The class name.
	 */	
	M.removeClass = function (el, className) 
	{
		if (el) 
		{
			el.className = el.className.replace(className, '').replace(/^\s+|\s+$/g, "");	
		}
	};

	/**
	 * クラスが定義されていなければ追加、定義されていれば削除する
	 * @methodOf YAHOO.JP.lib.mics
	 * @name toggleClass
	 * @static
	 * @param {Object} el DOM要素
	 * @param {String} className クラス名
	 * @param {Boolean} force 省略可。trueにすると強制追加, falseにすると強制削除
	 */
	M.toggleClass = function (el, className, force)
	{
		if (el) 
		{
			var remove = (typeof force === 'boolean') ? !force : this.hasClass(el, className);
			this[(remove ? 'remove' : 'add') + 'Class'](el, className);
		}
	};

	/**
	 * 指定したクラス名同士を交換する
	 * @methodOf YAHOO.JP.lib.mics
	 * @name switchClass
	 * @static
	 * @param {Object} el クラスを取得する要素
	 * @param {String} srcClass 入れ替え前のクラス名
	 * @param {String} dstClass 入れ替え語のクラス名
	 */
	M.switchClass = function (el, srcClass, dstClass) {
		if (el) {
			var classStr = el.className,
				classList = classStr.split(" "),
				tmp;
			if (classStr.match(srcClass) && srcClass !== "") {
				el.className = classStr.split(srcClass).join(dstClass);
			} else { 
				tmp = classList;
				if (!classStr.match(dstClass)) {
					tmp.push(dstClass);
				}
				el.className = tmp.join(" ");
			}
		}
	};

	/**
	 * イベントを追加する
	 * @methodOf YAHOO.JP.lib.mics
	 * @name addEvent
	 * @static
	 * @param {Object} el イベントを付加させるオブジェクト
	 * @param {String} type イベントタイプ
	 * @param {Function} fn イベント実行時のコールバック関数
	 */
	M.addEvent = function (el, type, fn) {
		if (el) {
			if (el.attachEvent) {
				el.attachEvent("on" + type, fn);
			} else if (el.addEventListener) {
				el.addEventListener(type, fn, false);
			} else {
				el["on" + type] = fn;
			}
		}
	};

	/**
	 * イベントを削除する
	 * @methodOf YAHOO.JP.lib.mics
	 * @name removeEvent
	 * @static
	 * @param {Object} el イベントを削除するオブジェクト
	 * @param {String} type イベントタイプ
	 * @param {Function} fn イベント実行時のコールバック関数
	 */
	M.removeEvent = function (el, type, fn) {
		if (el) {
			if (el.detachEvent) {
				el.detachEvent("on" + type, fn);
			} else if (el.removeEventListener) {
				el.removeEventListener(type, fn, false);
			} else {
				el["on" + type] = null;
			}
		}
	};

	/**
	 * イベントをキャンセルする
	 * @methodOf YAHOO.JP.lib.mics
	 * @name preventDefault
	 * @static
	 * @param {Object} e イベントオブジェクト
	 */
	M.preventDefault = function (e) {
		var eo = e || window.event;
		if (eo.preventDefault) {
			eo.preventDefault();
		} else { 
			eo.returnValue = false;
		}
	};

	/**
	 * イベントの伝播をキャンセルする
	 * @methodOf YAHOO.JP.lib.mics
	 * @name stopPropagation
	 * @static
	 * @param {Object} e イベントオブジェクト
	 */
	M.stopPropagation = function (e) {
		var eo = e || window.event;
		if (eo.stopPropagation) {
			eo.stopPropagation();
		} else { 
			eo.cancelBubble = false;
		}
	};

	/**
	 * 指定したコンテキストから関数を実行する関数を返す	
	 * @methodOf YAHOO.JP.lib.mics
	 * @name bind
	 * @static
	 * @param {Function} fn 実行するメソッド
	 * @param {Object} ctx コンテキスト（関数の呼び出しオブジェクト）
	 * @return {Function}
	 */
	M.bind = function (fn, ctx)
	{
		ctx = ctx || fn;
		return function () {
			fn.call(ctx);
		};
	};

	/**
	 * チェックボックスをチェックしたときに、ボタン押下可能にする
	 * @methodof YAHOO.JP.lib.mics
	 * @name toggleCheckButtonStatus
	 * @static
	 * @param {String} id チェックボックスつきボタンのid名
	 */
	
	M.toggleCheckButtonStatus = function (id) {
		var o = document.getElementById(id),
			checkbox = o.getElementsByTagName("input")[0],
			button = o.getElementsByTagName("a")[0];
		checkbox.checked = false;
		button.className = "off";
		M.addEvent(button, "click", function (e) {
			if (button.className === "off") {
				M.preventDefault(e);
			}
		});
		M.addEvent(checkbox, "click", function () {
			button.className = (checkbox.checked === true) ? null : "off";
		});
	};

	/**
	 * ナビゲーション付き画像リストを生成します。
	 * @class
	 * @member YAHOO.JP.lib.mics
	 * @name Imagelist
	 * @param {Object} args 「id:要素のid」「listName:リストのクラス名」「viewName:ビューエリアのクラス名」「scroll:1ページのスクロール数」を設定
	 */
	M.Imagelist = function (args) {
		if (!args) {
			return;
		}
		if (!args.id) {
			return;
		}
		if (!args.listName) {
			return;
		}
		if (!args.viewName) {
			return;
		}
		if (!args.scroll) {
			return;
		}
		M.addEvent(window, "load", M.bind(function () {
			this.initialize(args);
			this.fixListLength();
			this.set();
			if (/*@cc_on!@*/true) {
				this.flick();
			}
			this.makeIndicator();
		}, this));
	};


	M.Imagelist.prototype = {
		/**
		 * 画像リストの左端の位置をセットする
		 * @method setPosition
		 * @param {Number} val 数値
		 */
		setPosition: function (val) {
			if (this.isWebkit) {
				this.photoListMain.style.webkitTransform = "translate(" + val + "px,0)";//android1.6
				this.photoListMain.style.webkitTransform = "translate3d(" + val + "px,0,0)";
			} else { 
				this.photoListMain.style.left = val + "px";
			}
		},

		/***
		 * 初期化する
		 * @method init
		 */
		initialize: function (args) {
			this.args = args;
			this.d = document;
			this.o = this.d.getElementById(this.args.id);
			this.photoListMain = M.getClass(this.o, this.args.listName, "*")[0];
			this.w_li = this.photoListMain.getElementsByTagName("li")[0].offsetWidth;
			this.n_li = this.photoListMain.getElementsByTagName("li").length;
			this.w_ul = this.w_li * this.n_li;
			this.w_view = M.getClass(this.o, this.args.viewName, "*")[0].offsetWidth;
			this.isIndicate = (this.args.indicate) ? true : false;
			this.isAnim = false;
			this.n_scroll = this.args.scroll;
			this.n_sets = this.n_li / this.n_scroll;
			this.isTouch = (typeof this.d.ontouchstart === "object") && navigator.userAgent.toLowerCase().indexOf("android") === -1;
			this.isWebkit = (typeof this.photoListMain.style.webkitTransform === "string")  && (typeof onwebkittransitionend === "object");
			this.btn_prev = M.getClass(this.o, "prev", "li")[0];
			this.btn_next = M.getClass(this.o, "next", "li")[0];
			window.clearTimeout(this.timerId);
			this.setPosition(0);
		},

		/***
		 * ビューに満たない画像枚数のリストの場合、リストの長さを調整する
		 * @method fixListLength
		 */
		fixListLength: function () {
			var new_li;
			while (this.n_li % this.n_scroll !== 0) {
				new_li = this.d.createElement("li");
				this.photoListMain.insertBefore(new_li, this.photoListMain.lastChild.nextSibling);
				this.n_li = this.n_li + 1;
			}
			this.initialize(this.args);
		},

		/**
		 * 現在のリストの左端の座標を返す
		 * @method current
		 * @return {Number}
		 */
		current: function () {
			var ret = 0,
				tmp;
			if (this.isWebkit) {
				tmp = this.photoListMain.style.webkitTransform;
				if (tmp.indexOf("translate(") !== -1) {//android1.6
					tmp = tmp.split("translate(")[1];
				}
				else if (tmp.indexOf("translate3d(") !== -1) {
					tmp = tmp.split("translate3d(")[1];
				}
				if (tmp.indexOf("px") !== -1) {
					ret = tmp.split("px")[0];
				}
			} else { 
				tmp = this.photoListMain.style.left;
				if (tmp.indexOf("px") !== -1) {
					ret = tmp.split("px)")[0];
				}
			}
			return parseInt(ret, 10);
		},

		/**
		 * 数値に対し、最も近い画像開始位置を返す
		 * @method roundToGrid
		 * @param {Number} val 数値
		 * @return {Number}
		 */
		roundToGrid: function (val) {
			if (val % (this.w_li * this.n_scroll) === 0) {
				return val;
			}
			var gridNum = 0,
				i,
				l,
				tmpGrid;
			for (i = 0, l = this.photoListMain.getElementsByTagName("li").length; i < l - 1; i = i + this.n_scroll) {
				tmpGrid = -this.w_li * i;
				gridNum = (tmpGrid > val) ? i : gridNum;
			}
			gridNum = (Math.abs(val - (-gridNum * this.w_li)) < Math.abs(val - (-(gridNum + this.n_scroll) * this.w_li))) ?  gridNum : gridNum + this.n_scroll;
			return -gridNum * this.w_li;
		},

		/**
		 * ナビゲーション（インジケータおよび前後ボタン）の状態を変更する
		 * @method indicate
		 */	
		indicate: function () {
			var c =  -1 * this.current() / (this.w_li * this.n_scroll),
				i,
				l;
			if (this.isIndicate) {
				for (i = 0, l = this.indicator_li.length; i < l; i = i + 1) {
					this.indicator_li[i].className = "";
				}
				this.indicator_li[parseInt(c, 10)].className = "current";
			}
			
			if (this.btn_prev && this.btn_next) {
				//change button status
				this.btn_prev.style.cursor = "pointer";
				this.btn_next.style.cursor = "pointer";
				this.btn_prev.className = "prev";
				this.btn_next.className = "next";
				if (parseInt(c, 10) === this.n_sets - 1) {
					this.btn_next.style.cursor = "default";
					this.btn_next.className = "nextDisable";
				}
				if (this.roundToGrid(this.current()) === 0) {
					this.btn_prev.style.cursor = "default";
					this.btn_prev.className = "prevDisable";
				}
			}
		},

		/**
		 * 指定した開始位置から、終了位置へアニメーション移動する
		 * @method move
		 */
		move: function (start, end) {
			this.indicate();
			if (end >= 0) {
				end = 0;
			} else if (end  <=  this.w_view - this.w_ul) {
				end = this.roundToGrid(this.w_view - this.w_ul);
			}
			if (start === end) {
				return;
			}
			this.isAnim = true;
			if (this.isWebkit) {
				this.photoListMain.style.webkitTransition = "-webkit-transform 0.5s ease-out";
				this.setPosition(end);
				M.addEvent(this.photoListMain, "webkitTransitionEnd", M.bind(function () {
					M.removeEvent(this.photoListMain, "webkitTransitionEnd", arguments.callee);
					this.photoListMain.style.webkitTransition = "none";
					this.isAnim = false;
					this.indicate();
				}, this));
			}
			else {
				//webkit以外
				var scope = this,
					tmpStart = start,
					tmpEnd = end,
					cnt = 0,
					accuracy = 20,
					ease = 100; // -100 <= ease <= 100
				window.clearTimeout(this.timerId);
				
				(function () {
					//arguments.calleeによって再帰する。
				    if (cnt++ < accuracy) {
				        var c = cnt / accuracy,
				        	x = (tmpEnd - tmpStart) * (c + ease / (100 * Math.PI) * Math.sin(Math.PI * c)) + tmpStart;
						scope.setPosition(x);
				        scope.timerId = window.setTimeout(arguments.callee, 20);
				    } else { 
						window.clearTimeout(scope.timerId);
						scope.isAnim = false;
						scope.indicate();
					}
				})();
			}
		},
		/**
		 * 指定した枚数だけ画像リストを進める
		 * @method next
		 * @param {Number} jump 画像を送る枚数
		 */
		next: function (jump) {
			if (this.isAnim) {
				return;
			}
			var c = this.current();
			this.move(c, this.roundToGrid(c - this.w_li * jump));
		},
		/**
		 * 指定した枚数だけ画像リストを戻す
		 * @method prev
		 * @param {Number} jump 画像を送る枚数
		 */
		prev: function (jump) {
			if (this.isAnim) {
				return;
			}
			var c = this.current();
			this.move(c, this.roundToGrid(c + this.w_li * jump));
		},
		/***
	 	 * ナビゲーション（前後ボタン）をセットする
		 * @method set
		 */
		set: function () {
			if (this.btn_prev && this.btn_next) {
				this.btn_prev.style.cursor = "pointer";
				this.btn_next.style.cursor = "pointer";
				this.btn_prev.style.display = "block";
				this.btn_next.style.display = "block";
				M.addEvent(this.btn_prev, "mousedown", M.bind(function () {
					this.prev(this.n_scroll);
				}, this));
				M.addEvent(this.btn_next, "mousedown", M.bind(function () {
					this.next(this.n_scroll);
				}, this));
			}
		},
		/***
		 * 画像リストをフリック可能にする
		 * @method flick
		 */
		flick: function () {
			var scope = this,
				i,
				l,
				c,
				isSlide = false,
				startx = 0,
				starty = 0,
				endx = 0,
				endy = 0,
				strength = 0,
				endx_old = 0,
				endy_old = 0,
				threshold = 40,
				bound = this.w_view,
				tmpLink = this.photoListMain.getElementsByTagName("a"),
				tmpHref = [],
				evDown = (this.isTouch) ? "touchstart" : "mousedown",
				evMove = (this.isTouch) ? "touchmove" : "mousemove",
				evUp = (this.isTouch) ? "touchend" : "mouseup",
				onMove,
				onUp,
				onDown;
			
			for (i = 0, l = tmpLink.length; i < l; i = i + 1) {
				tmpHref[i] = tmpLink[i].href;
			}

			/**
			 * @member M.Imagelist
			 * @param {Object} e イベントオブジェクト
			 */
			onMove = function (e) {
				endx_old = endx;
				endy_old = endy;
				isSlide = true;
				if (scope.isTouch) {
					if (Math.abs(endx - startx) > threshold) {
						M.preventDefault(e);
					}
					endx = e.touches[0].pageX;
					endy = e.touches[0].pageY;
				} else { 
					endx = e.pageX;
					endy = e.pageY;
				}
				var dst = c + endx - startx;
				strength = endx - endx_old;
				if (dst > bound) {
					dst = bound;
					strength = 0;
				}
				else if (dst <= scope.roundToGrid(scope.w_view - scope.w_ul) - bound) {
					dst = scope.roundToGrid(scope.w_view - scope.w_ul) - bound;
					strength = 0;
				}
				scope.setPosition(dst);
			};

			/**
			 * @member M.Imagelist
			 * @param {Object} e イベントオブジェクト
			 */
			onUp = function (e) {
				var i, l, dst;
				if (isSlide) {
					for (i = 0, l = tmpLink.length; i < l; i = i + 1) {
						tmpLink[i].href = null;
					}
					isSlide = false;
				} else { 
					for (i = 0, l = tmpLink.length; i < l; i = i + 1) {
						tmpLink[i].href = tmpHref[i];
					}	
				}
				c = scope.current();
				dst = c + strength * 5;
				scope.move(c, scope.roundToGrid(dst));
				M.removeEvent(scope.photoListMain, evMove, onMove);
				M.removeEvent(scope.photoListMain, evUp, onUp);
				if (!scope.isTouch) {
					M.removeEvent(scope.d, "mouseup", onUp);
				}
			};

			/**
			 * @member M.Imagelist
			 * @param {Object} e イベントオブジェクト
			 */
			onDown = function (e) {
				if (scope.isAnim) {
					if (scope.isWebkit) {
						scope.photoListMain.style.webkitTransition = "none";
					}
					window.clearTimeout(scope.timerId);
					scope.isAnim = false;
				}
				c = scope.current();
				if (scope.isTouch) {
					startx = e.touches[0].pageX;
					starty = e.touches[0].pageY;
				} else { 
					startx = e.pageX;
					starty = e.pageY;
				}
				
				strength = 0;
				endx_old = 0;
				endy_old = 0;
				isSlide = false;
				M.addEvent(scope.photoListMain, evMove, onMove);
				M.addEvent(scope.photoListMain, evUp, onUp);
				if (!scope.isTouch) {
					M.addEvent(scope.d, "mouseup", onUp);
				}
			};
			M.addEvent(this.photoListMain, evDown, onDown);
		},
		/**
		 * ナビゲーション（インジケータ）を表示させる
		 * @method makeIndicator
		 */	
		makeIndicator: function () {
			if (this.isIndicate) {
				var indicator_ul = this.d.createElement("ul"),
					i,
					li;
				indicator_ul.className = "imagelistIndicator";
				this.o.insertBefore(indicator_ul, this.o.lastChild);
				for (i = 0; i < this.n_sets; i = i + 1) {
					li = this.d.createElement("li");
					indicator_ul.insertBefore(li, indicator_ul.firstChild);
				}
				this.indicator_li = indicator_ul.childNodes;
			}
			this.indicate();
		}
	};

	/**
	 * 検索ボックス
	 * @class
	 * @member YAHOO.JP.lib.mics
	 * @name Search
	 * @param {Object} node DOM要素
	 */
	M.Search = function (node) {
		this.initialize(node);
	};
	M.Search.prototype = {
		/**
		 * 初期化
		 * @method initialize
		 * @param {Object} node 親要素のCSSセレクタかDOM要素
		 */
		initialize: function (node)
		{
			node = document.getElementById(node);
			if (!node) {
				return false;
			}
			// common nodes.
			this.input = M.getClass(node, "search", "input")[0];
			this.clear = M.getClass(node, "clear", "*")[0];
			this.form =  node.getElementsByTagName("form")[0];
			this.placeHolder = M.getClass(node, "placeHolder", "*")[0];
			var submit  = M.getClass(node, "submit", "*")[0],
				cancel,
				select,
				i,
				l;
			// common events.
			M.addEvent(submit, "click", M.bind(this.submit, this));
			M.addEvent(this.clear, "mousedown", M.bind(this.clearInput, this));
			M.addEvent(this.clear, "mouseup", M.bind(this.clearInputAfter, this));
			setInterval(M.bind(this.checkInput, this), 10);

			// set default text
			this.setPlaceholder();

			// not simple mode
			if (!M.hasClass(node, "simple"))
			{
				//create "cancel".
				this.ul = node.getElementsByTagName("ul")[0];
				cancel = document.createElement("li");
				M.addClass(cancel, "cancel");
				cancel.innerHTML = "<a title='キャンセル' x-hidden-value='cancel'>キャンセル</a>";
				this.ul.appendChild(cancel);

				// nodes.
				this.type = M.getClass(node, "hidden", "input")[0];
				this.lis  = node.getElementsByTagName("li");
				this.label = M.getClass(node, "label", "div")[0];
				this.frame = M.getClass(node, "frame", "div")[0];
				select = M.getClass(node, "select", "*")[0];

				// set events.
				M.addEvent(select, "click", M.bind(this.toggleList, this));
				for (i = 0, l = this.lis.length; i < l; i = i + 1)
				{
					M.addEvent(this.lis[i], "click", (function (scope) {
						return function (e) {
							e = (!e) ? window.event : e;
							scope.setType(e);
						};
					})(this));
				}
			}
		},
		/**
		 * 検索種類選択のプルダウンを開いたり閉じたり
		 * @method toggleList
		 */
		toggleList: function ()
		{
			M.toggleClass(this.ul, "show");
		},

		/**
		 * 検索の種類を設定
		 * @method setType
		 * @param {Object} e イベントオブジェクト
		 */
		setType: function (e)
		{
			var target = (!e.target) ? e.srcElement : e.target,
				labelName = target.getAttribute("title"),
				i,
				l,
				node;
			if (labelName !== null)
			{
				if (M.hasClass(target.parentNode, "cancel")) {
					this.toggleList();
					return;
				}
				M.addClass(this.label, "show");
				this.label.innerHTML = "<div class='inner'>" + labelName + "</div>";
				this.frame.style.paddingLeft = (50 + this.label.offsetWidth) + "px";
			}
			else
			{
				M.removeClass(this.label, "show");
				this.frame.style.paddingLeft = "50px";
			}
			this.input.focus();
			this.type.setAttribute("value", target.getAttribute("x-hidden-value"));

			// チェックマークを付ける
			for (i = 0, l = this.lis.length; i < l; i = i + 1)
			{
				node = this.lis[i];
				M.toggleClass(node, "selected", node.firstChild === target);
			}
			this.toggleList();
		},

		/**
		 * 初期キーワードを入れる
		 * @method setPlaceholder
		 * @param {String} str キーワードの文字列
		 */
		setPlaceholder: function (str)
		{
			if (this.input.value === "") {
				this.placeHolder.style.display = "block";
			}
			M.addEvent(this.input, "focus", M.bind(function () {
				this.placeHolder.style.display = "none";
			}, this));
		},

		/**
		 * テキストフィールドに文字がはいっていないかを定期的にチェック
		 * @method checkInput
		 */
		checkInput: function ()
		{
			var hasValue = (this.input.value.length > 0) && (this.input.value !== this.placeHolderText);
			M.toggleClass(this.clear, "show", hasValue);
		},

		/**
		 * テキストフィールドの中身をクリア
		 * @method clearInput
		 */
		clearInput: function (e)
		{
			this.clearTouch = true;
			this.input.value = "";
			M.removeClass(this.clear, "show");
		},

		/**
		 * クリアボタン押下時に検索ボタンを押し間違えないように追加した
		 * フラグを追加してるので、クリアボタン押下後に解除
		 * @method clearInputAfter
		 */
		clearInputAfter: function ()
		{
			window.setTimeout(M.bind(function () {
				this.clearTouch = false;
			}, this), 100);
		},

		/**
		 * フォームを送信
		 * @method submit
		 */
		submit: function ()
		{
			if (this.clearTouch) {
				return;
			}
			this.form.submit();
		}
	};

	/**
	 * モジュールの開閉を行う
	 * @methodof YAHOO.JP.lib.mics
	 * @name menuExpand
	 * @static
	 * @param {Object} args 「id:要素のid」「open:デフォルトで開くモジュールのインデックス（またはインデックスの配列）」を設定
	 */
	
	M.menuExpand = function (args) {
		if (!args) {
			return;
		}
		if (!args.id) {
			return;
		}
		var o = document.getElementById(args.id),
			ttl = M.getClass(o, "expandTitle", "*"),
			dl,
			tmp,
			i,
			j,
			l,
			l2;
		for (i = 0, l = ttl.length; i < l; i = i + 1) {
			ttl[i].style.cursor = "pointer";
			dl = ttl[i].parentNode;
			M.getClass(dl, "icon")[0].style.display = "block";
			M.switchClass(dl, "open", "close");
		}
		if (args.open !== undefined) {
			//openがnumberのとき
			if (typeof args.open === "number" && ttl[args.open]) {
				M.switchClass(ttl[args.open].parentNode, "close", "open");
			}
			//openがArrayのとき
			if (args.open instanceof Array) {
				for (i = 0, l = ttl.length; i < l; i = i + 1) {
					for (j = 0, l2 = args.open.length; j < l2; j = j + 1) {
						if (typeof j === "number" && i === args.open[j]) {
							M.switchClass(ttl[args.open[j]].parentNode, "close", "open");
						}
					}
				}
			}
		}
		for (i = 0, l = ttl.length; i < l; i = i + 1) {
			tmp = ttl[i];
			M.addEvent(tmp, "click", M.bind(function () {
				dl = this.parentNode;
				if (dl.className === "close") {
					M.switchClass(dl, "close", "open");
				}
				else if (dl.className === "open") {
					M.switchClass(dl, "open", "close");
				}
			}, tmp)); 	
		}
	};

	M.addEvent(window, "load", M.initLayout);
})();
